@@ -1,4 +1,4 @@
-# Copyright 2024 Macéo Tuloup
+# Copyright 2025 Macéo Tuloup
 
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,22 +12,20 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-__all__ = [
-    "Archiver", "ArchiverGNU", "ArchiverAR", "ArchiverLLVM_AR", "ArchiverMSVC"
-]
-
 import typing as T
 
 from .common import Archiver
-from .gnu import ArchiverGNU, ArchiverAR, ArchiverLLVM_AR
+from .gnu import ArchiverGNU, ArchiverAR, ArchiverLLVM_AR, ArchiverMinGW
 from .msvc import ArchiverMSVC
 
 
 _archiver_types: T.Dict[str, T.Callable[[], Archiver]] = {
+    "default": ArchiverGNU,
     "gnu": ArchiverGNU,
     "ar": ArchiverAR,
     "llvm-ar": ArchiverLLVM_AR,
-    "msvc": ArchiverMSVC
+    "msvc": ArchiverMSVC,
+    "mingw": ArchiverMinGW
 }
 
 
