@@ -1,4 +1,4 @@
-# Copyright 2024 Macéo Tuloup
+# Copyright 2025 Macéo Tuloup
 
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -44,3 +44,10 @@ class ArchiverLLVM_AR(ArchiverGNU):
 
     def __init__(self, path: str = "llvm-ar"):
         super().__init__(path)
+
+
+class ArchiverMinGW(ArchiverGNU):
+    type: T.ClassVar = "mingw"
+
+    def __init__(self, path: str = "x86_64-w64-mingw32-gcc-ar"):
+        super().__init__(path)
\ No newline at end of file
