@@ -1,4 +1,4 @@
-# Copyright 2024 Macéo Tuloup
+# Copyright 2025 Macéo Tuloup
 
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,8 +22,8 @@ class Compiler(Tool, abc.ABC):
     type: T.ClassVar = ""
     obj_extension: T.ClassVar = ""
 
-    def __init__(self, path: str):
-        Tool.__init__(self, path)
+    def __init__(self, path: T.Union[str, T.List[str]], translation_dict: T.Union[T.Dict[str, T.List[str]], None] = None):
+        Tool.__init__(self, path, translation_dict)
 
     @abc.abstractmethod
     def format_args(self, defines: T.List[str], includedirs: T.List[str], flags: T.List[str] = []) -> T.List[str]:
