@@ -1,4 +1,4 @@
-# Copyright 2024 Macéo Tuloup
+# Copyright 2025 Macéo Tuloup
 
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,18 +12,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-__all__ = [
-    "Linker", "LinkerGNU", "LinkerLD", "LinkerGCC", "LinkerClang", "LinkerGPlusPlus", "LinkerClangPlusPlus", "LinkerMSVC", "LinkerClang_CL"
-]
-
 import typing as T
 
 from .common import Linker
-from .gnu import LinkerGNU, LinkerLD, LinkerGCC, LinkerClang, LinkerGPlusPlus, LinkerClangPlusPlus
+from .gnu import LinkerGNU, LinkerLD, LinkerGCC, LinkerClang, LinkerGPlusPlus, LinkerClangPlusPlus, LinkerMinGW, LinkerMinGWPlusPlus, LinkerMinGWLD
 from .msvc import LinkerMSVC, LinkerClang_CL
 
 
 _linker_types: T.Dict[str, T.Callable[[], Linker]] = {
+    "default": LinkerGNU,
     "gnu": LinkerGNU,
     "ld": LinkerLD,
     "gcc": LinkerGCC,
@@ -31,7 +28,10 @@ _linker_types: T.Dict[str, T.Callable[[], Linker]] = {
     "clang": LinkerClang,
     "clang++": LinkerClangPlusPlus,
     "msvc": LinkerMSVC,
-    "clang-cl": LinkerClang_CL
+    "clang-cl": LinkerClang_CL,
+    "mingw": LinkerMinGW,
+    "mingw++": LinkerMinGWPlusPlus,
+    "mingw-ld": LinkerMinGWLD
 }
 
 
